import axios from '@/utils/axios'

/**
 * 分页查询职位
 * @param {Object} page - 分页对象
 * @param {Object} entity - 职位实体类对象
 * @returns {Promise} - 返回一个 Promise 对象
 */
export function pageRes(page, entity) {
  return axios.post('/recruit/position/page/res', {
    ...page,
    ...entity
  })
}

/**
 * 获取职位列表
 * @param {Object|null} entity - 职位实体类对象，可为空
 * @returns {Promise} - 返回一个 Promise 对象
 */
export function getPositionList(entity = null) {
  return axios.post('/recruit/position/list', entity)
}

/**
 * 新增职位
 * @param {Object} entity - 职位实体类对象
 * @returns {Promise} - 返回一个 Promise 对象
 */
export function addPosition(entity) {
  return axios.post('/recruit/position/add', entity)
}

/**
 * 修改职位
 * @param {Object} entity - 职位实体类对象
 * @returns {Promise} - 返回一个 Promise 对象
 */
export function updatePosition(entity) {
  return axios.post('/recruit/position/edit', entity)
}

/**
 * 删除职位
 * @param {Object} entity - 职位实体类对象，需包含 id
 * @returns {Promise} - 返回一个 Promise 对象
 */
export function deletePosition(entity) {
  return axios.post('/recruit/position/del', entity)
}

/**
 * 投递简历给职位
 * @param {Object} entity - 简历实体类对象
 * @returns {Promise} - 返回一个 Promise 对象
 */
export function addDelivery(entity) {
  return axios.post('/recruit/resume/add_delivery', entity)
}

/**
 * 根据岗位id去查询该岗位下面的简历
 * @param {String} positionId - 岗位的id
 * @returns {Promise} - 返回一个 Promise 对象
 */
export function getResumesByPositionId(positionId) {
  return axios.get(`/recruit/resume/getResumesByPositionId?positionId=${positionId}`)
}
